/*
 *  The Mana World
 *  Copyright (C) 2004  The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef GUICHANFWD_H
#define GUICHANFWD_H

namespace gcn
{
    class ActionListener;
    class AllegroGraphics;
    class AllegroImage;
    class AllegroImageLoader;
    class AllegroInput;
    class BasicContainer;
    class Button;
    class CheckBox;
    class ClipRectangle;
    class Color;
    class Container;
    class DefaultFont;
    class DropDown;
    class Exception;
    class FocusHandler;
    class Font;
    class Graphics;
    class Gui;
    class Icon;
    class Image;
    class ImageFont;
    class ImageLoader;
    class Input;
    class Key;
    class KeyInput;
    class KeyListener;
    class Label;
    class ListBox;
    class ListModel;
    class MouseInput;
    class MouseListener;
    class OpenGLGraphics;
    class OpenGLImage;
    class OpenGLSDLImageLoader;
    class RadioButton;
    class Rectangle;
    class ScrollArea;
    class SDLGraphics;
    class SDLImage;
    class SDLImageLoader;
    class SDLInput;
    class Slider;
    class TextBox;
    class TextField;
    class Widget;
    class Window;
}

#endif
